#
# spec file for package python3-beautifulsoup4
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-beautifulsoup4
Version:        4.4.0
Release:        4.1
Summary:        HTML/XML Parser for Quick-Turnaround Applications Like Screen-Scraping
License:        MIT
Group:          Development/Libraries/Python
Url:            http://www.crummy.com/software/BeautifulSoup/
Source:         https://pypi.python.org/packages/source/b/beautifulsoup4/beautifulsoup4-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-html5lib
BuildRequires:  python3-lxml
# Documentation requirements:
BuildRequires:  python3-Sphinx
# Test requirements:
BuildRequires:  python3-nose
Requires:       python3-html5lib
Requires:       python3-lxml
BuildArch:      noarch

%description
Beautiful Soup is a Python HTML/XML parser designed for quick turnaround
projects like screen-scraping. Three features make it powerful:

* Beautiful Soup won't choke if you give it bad markup. It yields a parse tree
  that makes approximately as much sense as your original document. This is
  usually good enough to collect the data you need and run away

* Beautiful Soup provides a few simple methods and Pythonic idioms for
  navigating, searching, and modifying a parse tree: a toolkit for dissecting a
  document and extracting what you need. You don't have to create a custom
  parser for each application

* Beautiful Soup automatically converts incoming documents to Unicode and
  outgoing documents to UTF-8. You don't have to think about encodings, unless
  the document doesn't specify an encoding and Beautiful Soup can't autodetect
  one. Then you just have to specify the original encoding

Beautiful Soup parses anything you give it, and does the tree traversal stuff
for you. You can tell it "Find all the links", or "Find all the links of class
externalLink", or "Find all the links whose urls match "foo.com", or "Find the
table heading that's got bold text, then give me that text."

Valuable data that was once locked up in poorly-designed websites is now within
your reach. Projects that would have taken hours take only minutes with
Beautiful Soup.
Beautiful Soup.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Libraries/Python
Recommends:     %{name} = %{version}

%description doc
Documentation and help files for %{name}


%prep
%setup -q -n beautifulsoup4-%{version}

%build
python3 setup.py build
cd doc && make html

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS.txt COPYING.txt
%{python3_sitelib}/bs4/
%{python3_sitelib}/beautifulsoup4-%{version}-py*.egg-info

%files doc
%defattr(-,root,root)
%doc NEWS.txt README.txt TODO.txt doc/build/html

%changelog
* Wed Jul 15 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.4.0:
  * Especially important changes:
    + Added a warning when you instantiate a BeautifulSoup object
    without explicitly naming a parser. [bug=1398866]
    + __repr__ now returns an ASCII bytestring in Python 2, and a
    Unicode string in Python 3, instead of a UTF8-encoded bytestring
    in both versions. In Python 3, __str__ now returns a Unicode
    string instead of a bytestring. [bug=1420131]
    + The `text` argument to the find_* methods is now called
    `string`, which is more accurate. `text` still works, but
    `string` is the argument described in the documentation. `text`
    may eventually change its meaning, but not for a very long
    time. [bug=1366856]
    + Changed the way soup objects work under copy.copy(). Copying a
    NavigableString or a Tag will give you a new NavigableString
    that's equal to the old one but not connected to the parse
    tree. Patch by Martijn Peters. [bug=1307490]
    + Started using a standard MIT license. [bug=1294662]
    + Added a Chinese translation of the documentation by Delong .w.
  * New features:
    + Introduced the select_one() method, which uses a CSS selector
    but only returns the first match, instead of a list of
    matches. [bug=1349367]
    + You can now create a Tag object without specifying a
    TreeBuilder. Patch by Martijn Pieters. [bug=1307471]
    + You can now create a NavigableString or a subclass just by
    invoking the constructor. [bug=1294315]
    + Added an `exclude_encodings` argument to UnicodeDammit and to
    the Beautiful Soup constructor, which lets you prohibit the
    detection of an encoding that you know is wrong. [bug=1469408]
    + The select() method now supports selector grouping. Patch by
    Francisco Canas [bug=1191917]
  * Bug fixes:
    + Fixed yet another problem that caused the html5lib tree builder
    to create a disconnected parse tree. [bug=1237763]
    + Force object_was_parsed() to keep the tree intact even when an
    element from later in the document is moved into
    place. [bug=1430633]
    + Fixed yet another bug that caused a disconnected tree when
    html5lib copied an element from one part of the tree to
    another. [bug=1270611]
    + Fixed a bug where Element.extract() could create an infinite
    loop in the remaining tree.
    + The select() method can now find tags whose names contain
    dashes. Patch by Francisco Canas. [bug=1276211]
    + The select() method can now find tags with attributes whose
    names contain dashes. Patch by Marek Kapolka. [bug=1304007]
    + Improved the lxml tree builder's handling of processing
    instructions. [bug=1294645]
    + Restored the helpful syntax error that happens when you try to
    import the Python 2 edition of Beautiful Soup under Python
    3. [bug=1213387]
    + In Python 3.4 and above, set the new convert_charrefs argument
    to the html.parser constructor to avoid a warning and future
    failures. Patch by Stefano Revera. [bug=1375721]
    + The warning when you pass in a filename or URL as markup will
    now be displayed correctly even if the filename or URL is a
    Unicode string. [bug=1268888]
    + If the initial <html> tag contains a CDATA list attribute such
    as 'class', the html5lib tree builder will now turn its value
    into a list, as it would with any other tag. [bug=1296481]
    + Fixed an import error in Python 3.5 caused by the removal of the
    HTMLParseError class. [bug=1420063]
    + Improved docstring for encode_contents() and
    decode_contents(). [bug=1441543]
    + Fixed a crash in Unicode, Dammit's encoding detector when the
    name of the encoding itself contained invalid
    bytes. [bug=1360913]
    + Improved the exception raised when you call .unwrap() or
    .replace_with() on an element that's not attached to a tree.
    + Raise a NotImplementedError whenever an unsupported CSS
    pseudoclass is used in select(). Previously some cases did not
    result in a NotImplementedError.
    + It's now possible to pickle a BeautifulSoup object no matter
    which tree builder was used to create it. However, the only tree
    builder that survives the pickling process is the
    HTMLParserTreeBuilder ('html.parser'). If you unpickle a
    BeautifulSoup object created with some other tree builder,
    soup.builder will be None. [bug=1231545]
* Tue Oct 22 2013 toddrme2178@gmail.com
- update to 4.3.2
  * Fixed a bug in which short Unicode input was improperly encoded to
    ASCII when checking whether or not it was the name of a file on
    disk. [bug=1227016]
  * Fixed a crash when a short input contains data not valid in
    filenames. [bug=1232604]
  * Fixed a bug that caused Unicode data put into UnicodeDammit to
    return None instead of the original data. [bug=1214983]
  * Combined two tests to stop a spurious test failure when tests are
    run by nosetests. [bug=1212445]
- update to 4.3.1
  * Fixed yet another problem with the html5lib tree builder, caused by
    html5lib's tendency to rearrange the tree during
    parsing. [bug=1189267]
  * Fixed a bug that caused the optimized version of find_all() to
    return nothing. [bug=1212655]
- update to 4.3.0
  * Instead of converting incoming data to Unicode and feeding it to the
    lxml tree builder in chunks, Beautiful Soup now makes successive
    guesses at the encoding of the incoming data, and tells lxml to
    parse the data as that encoding. Giving lxml more control over the
    parsing process improves performance and avoids a number of bugs and
    issues with the lxml parser which had previously required elaborate
    workarounds:
  - An issue in which lxml refuses to parse Unicode strings on some
    systems. [bug=1180527]
  - A returning bug that truncated documents longer than a (very
    small) size. [bug=963880]
  - A returning bug in which extra spaces were added to a document if
    the document defined a charset other than UTF-8. [bug=972466]
    This required a major overhaul of the tree builder architecture. If
    you wrote your own tree builder and didn't tell me, you'll need to
    modify your prepare_markup() method.
  * The UnicodeDammit code that makes guesses at encodings has been
    split into its own class, EncodingDetector. A lot of apparently
    redundant code has been removed from Unicode, Dammit, and some
    undocumented features have also been removed.
  * Beautiful Soup will issue a warning if instead of markup you pass it
    a URL or the name of a file on disk (a common beginner's mistake).
  * A number of optimizations improve the performance of the lxml tree
    builder by about 33%%, the html.parser tree builder by about 20%%, and
    the html5lib tree builder by about 15%%.
  * All find_all calls should now return a ResultSet object. Patch by
    Aaron DeVore. [bug=1194034]
* Thu Jun 27 2013 speilicke@suse.com
- Use upstream URL
- Update to version 4.2.1:
  + The default XML formatter will now replace ampersands even if they
    appear to be part of entities. That is, "&lt;" will become
    "&amp;lt;". The old code was left over from Beautiful Soup 3, which
    didn't always turn entities into Unicode characters.
    If you really want the old behavior (maybe because you add new
    strings to the tree, those strings include entities, and you want
    the formatter to leave them alone on output), it can be found in
    EntitySubstitution.substitute_xml_containing_entities(). [bug=1182183]
  + Gave new_string() the ability to create subclasses of
    NavigableString. [bug=1181986]
  + Fixed another bug by which the html5lib tree builder could create a
    disconnected tree. [bug=1182089]
  + The .previous_element of a BeautifulSoup object is now always None,
    not the last element to be parsed. [bug=1182089]
  + Fixed test failures when lxml is not installed. [bug=1181589]
  + html5lib now supports Python 3. Fixed some Python 2-specific
    code in the html5lib test suite. [bug=1181624]
  + The html.parser treebuilder can now handle numeric attributes in
    text when the hexidecimal name of the attribute starts with a
    capital X. Patch by Tim Shirley. [bug=1186242]
* Sat May 18 2013 toddrme2178@gmail.com
- Update to 4.2.0
  * The Tag.select() method now supports a much wider variety of CSS
    selectors.
  - Added support for the adjacent sibling combinator (+) and the
    general sibling combinator (~). Tests by "liquider". [bug=1082144]
  - The combinators (>, +, and ~) can now combine with any supported
    selector, not just one that selects based on tag name.
  - Added limited support for the "nth-of-type" pseudo-class. Code
    by Sven Slootweg. [bug=1109952]
  * The BeautifulSoup class is now aliased to "_s" and "_soup", making
    it quicker to type the import statement in an interactive session
    The alias may change in the future, so don't use this in code you're
    going to run more than once.
  * Added the 'diagnose' submodule, which includes several useful
    functions for reporting problems and doing tech support.
  - diagnose(data) tries the given markup on every installed parser,
    reporting exceptions and displaying successes. If a parser is not
    installed, diagnose() mentions this fact.
  - lxml_trace(data, html=True) runs the given markup through lxml's
    XML parser or HTML parser, and prints out the parser events as
    they happen. This helps you quickly determine whether a given
    problem occurs in lxml code or Beautiful Soup code.
  - htmlparser_trace(data) is the same thing, but for Python's
    built-in HTMLParser class.
  * In an HTML document, the contents of a <script> or <style> tag will
    no longer undergo entity substitution by default. XML documents work
    the same way they did before. [bug=1085953]
  * Methods like get_text() and properties like .strings now only give
    you strings that are visible in the document--no comments or
    processing commands. [bug=1050164]
  * The prettify() method now leaves the contents of <pre> tags
    alone. [bug=1095654]
  * Fix a bug in the html5lib treebuilder which sometimes created
    disconnected trees. [bug=1039527]
  * Fix a bug in the lxml treebuilder which crashed when a tag included
    an attribute from the predefined "xml:" namespace. [bug=1065617]
  * Fix a bug by which keyword arguments to find_parent() were not
    being passed on. [bug=1126734]
  * Stop a crash when unwisely messing with a tag that's been
    decomposed. [bug=1097699]
  * Now that lxml's segfault on invalid doctype has been fixed, fixed a
    corresponding problem on the Beautiful Soup end that was previously
    invisible. [bug=984936]
  * Fixed an exception when an overspecified CSS selector didn't match
    anything. Code by Stefaan Lippens. [bug=1168167]
- Build documentation and add doc sub-package
* Sat Jan 12 2013 toddrme2178@gmail.com
- Use explicit file list
- Fix building on openSUSE 12.1 and 12.2
- Use recommended lxml parser instead of native one
  (native fails fails for some python versions)
* Sat Jan 12 2013 idonmez@suse.com
- Fix runtime python dependency
* Wed Jan  9 2013 cfarrell@suse.com
- license update: MIT
  See COPYING.txt
* Mon Sep 10 2012 nmo.marques@gmail.com
- initial package from version 4.1.3
  - based on spec file from python-beautifulsoup
  - requires python >= 2.6
